@@ -146,18 +146,18 @@ def simple_extract(archive, archive_cmd, no_clobber=False):
         return
 
     # Extract archive
-    with open(archive) as fin:
+    with open(archive) as infile:
         if not pipe_cmd:
             if uses_stdin and not uses_stdout:
                 try:
-                    subprocess.run(extract_cmd, stdin=fin, check=True)
+                    subprocess.run(extract_cmd, stdin=infile, check=True)
                 except subprocess.CalledProcessError as e:
                     print(f"Error: Return Code = {e.returncode} {e.output or ''}")
             elif uses_stdin and uses_stdout:
                 with open(target, "w+") as outfile:
                     try:
                         subprocess.run(
-                            extract_cmd, stdin=fin, stdout=outfile, check=True
+                            extract_cmd, stdin=infile, stdout=outfile, check=True
                         )
                     except subprocess.CalledProcessError as e:
                         print(f"Error: Return Code = {e.returncode} {e.output or ''}")
@@ -169,7 +169,7 @@ def simple_extract(archive, archive_cmd, no_clobber=False):
                     print(f"Error: Return Code = {e.returncode} {e.output or ''}")
         else:
             with subprocess.Popen(
-                extract_cmd, stdin=fin, stdout=subprocess.PIPE
+                extract_cmd, stdin=infile, stdout=subprocess.PIPE
             ) as cmd:
                 try:
                     subprocess.run(pipe_cmd, stdin=cmd.stdout, check=True)
@@ -237,6 +237,7 @@ def fetch_archive(url, silent_download=False):
 
     _, target = os.path.split(url)
 
+    # determine which download tool to use
     if command_exists("curl"):
         if silent_download:
             fetch_cmd = shlex.split("curl -L -s -o -" + " " + url)
@@ -303,7 +304,7 @@ def main():
     parser.add_argument(
         "--version",
         action="version",
-        version="%(prog)s 0.2.1",
+        version="%(prog)s 0.2.3",
     )
     parser.add_argument(
         "--no_clobber",
@@ -362,7 +363,7 @@ def main():
         ),
     }
 
-    # sanitize inputs
+    # sanitize inputs, silently drop bad paths
     possibles = [os.path.realpath(x) for x in args]
     unfiltered = [x if os.path.exists(x) else None for x in possibles]
     archives = list(filter(lambda x: x is not None, unfiltered))
@@ -375,30 +376,29 @@ def main():
             continue
         archives.append(target)
 
-    if len(archives):
-        print(f"archives: {archives}")
-
-        # create an ArchiveCommand for each archive, pass them to simple_extract
-        for archive in archives:
-            print(f"Examining archive: {archive}")
-
-            pathname, filename = os.path.split(archive)
-            if pathname and archive not in url_archives:
-                os.chdir(pathname)
-
-            for extension, command in command_map.items():
-                if filename in glob.glob(extension):
-                    if archive not in glob_files:
-                        glob_files.append(archive)
-                        commands.append(command_map[extension])
-
-        if glob_files:
-            print(f"Files to extract: {glob_files}")
-    else:
+    if not archives:
         print("Nothing to do.")
         print("Try passing --help as an argument for more information.")
         sys.exit(0)
 
+    print(f"archives: {archives}")
+
+    # store an archive and an ArchiveCommand to be zipped and passed to simple_extract
+    for archive in archives:
+        print(f"Examining archive: {archive}")
+
+        pathname, filename = os.path.split(archive)
+        if pathname and archive not in url_archives:
+            os.chdir(pathname)
+
+        for extension, command in command_map.items():
+            if filename in glob.glob(extension):
+                if archive not in glob_files:
+                    glob_files.append(archive)
+                    commands.append(command)
+
+    print(f"Files to extract: {glob_files}")
+
     os.chdir(working_dir)
 
     # pass archives and their ArchiveCommand's to simple_extract
